from setuptools import setup

setup(
    name='dsb_spider',
    version='0.0.1',
    author='cjxh',
    author_email='chenjianxihang@duoshoubang.cn',
    url='http://m.fine3q.com/home-w/index.html',
    description=u'666',
    packages=['dsb_spider'],
    install_requires=[],
    python_requires='>=3.6'
)